<?php
  defined('ABSPATH') or die("Please don't run this script.");
class Simple_Days_Customize {

   public static function register ( $wp_customize ) {


      $wp_customize->add_panel( 'simple_days_setting', array(
        'priority'    => 0,
        'title'       => esc_html__('Simple Days settings', 'simple-days'),
      ));


      $wp_customize->add_section('simple_days_layout',array(
        'title' => esc_html__('Layout', 'simple-days'),
        'panel' => 'simple_days_setting',
      ));

  // Add Settings and Controls for Layout.
  $wp_customize->add_setting( 'simple_days_sidebar_layout', array(
    'default'           => '3',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_sidebar_layout', array(
    'label'    => esc_html__( 'Sidebar Layout', 'simple-days' ),
    'section'  => 'simple_days_layout',
    'type'     => 'radio',
    'choices'  => array(
      '1' => esc_html__( 'Left Sidebar', 'simple-days' ),
      '3' => esc_html__( 'Right Sidebar', 'simple-days' ),
      ),
    )
  );


  $wp_customize->add_setting('excerpt_length',array('sanitize_callback' => 'absint',));
  $wp_customize->add_control('excerpt_length',array(
    'section' => 'simple_days_layout',
    'type' => 'hidden'
  ));
  $wp_customize->selective_refresh->add_partial( 'excerpt_length', array(
         'selector' => '.post_card .summary',
  ));
  $wp_customize->add_setting( 'simple_days_excerpt_length_customize', array(
    'default' => 200,
    'sanitize_callback' => 'absint',
  ));
  $wp_customize->add_control( 'simple_days_excerpt_length_customize', array(
    'label' => esc_html__( 'Excerpt length', 'simple-days' ),
    'description' => esc_html__('default&#58;', 'simple-days').esc_html('200'),
    'section' => 'simple_days_layout',
    'type' => 'number',
    'input_attrs' => array(
    'min' => '0', 'step' => '1', 'max' => '600',),
  ));


         function simple_days_sanitize_radio( $input, $setting ){
         //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
            $input = sanitize_key($input);
            //get the list of possible radio box options
            $choices = $setting->manager->get_control( $setting->id )->choices;
            //return input if valid or return default option
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
        }

        function simple_days_sanitize_image_file( $file, $setting ) {
            //allowed file types
            $mimes = array(
                'jpg|jpeg|jpe' => 'assets/images/jpeg',
                'gif'          => 'assets/images/gif',
                'png'          => 'assets/images/png'
            );
            //check file type from file name
            $file_ext = wp_check_filetype( $file, $mimes );
            //if file has a valid mime type return it, otherwise return default
            return ( $file_ext['ext'] ? $file : $setting->default );
        }



      $wp_customize->add_section('simple_days_sns',array(
        'title' => esc_html__('Social Links','simple-days'),
        'panel' => 'simple_days_setting',
      ));

      $wp_customize->add_setting('sns_link',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('sns_link',array(
        'section' => 'simple_days_sns',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'sns_link', array(
         'selector' => '.sns_link_icon li:first-child',
      ));

      $wp_customize->add_setting( 'simple_days_single_social_link',array(
        'default'    => 1,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_single_social_link',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Social Links', 'simple-days'),
        'section' => 'simple_days_sns',
        'type' => 'checkbox',
      ));

      $sns_link_name = array(
        'none'               => '-',
        'facebook-square'    => esc_html__('Facebook', 'simple-days'),
        'feedly'             => esc_html__('Feedly', 'simple-days'),
        'flickr'             => esc_html__('Flickr', 'simple-days'),
        'github-square'      => esc_html__('Github', 'simple-days'),
        'google-plus-square' => esc_html__('Google+', 'simple-days'),
        'hatena'             => esc_html__('Hatena Bookmark', 'simple-days'),
        'instagram'          => esc_html__('Instagram', 'simple-days'),
        'line'               => esc_html__('Line', 'simple-days'),
        'linkedin'           => esc_html__('LinkedIn', 'simple-days'),
        'pinterest-square'   => esc_html__('Pinterest', 'simple-days'),
        'tumblr-square'      => esc_html__('Tumblr', 'simple-days'),
        'twitter-square'     => esc_html__('Twitter', 'simple-days'),
        'vimeo-square'       => esc_html__('Vimeo', 'simple-days'),
        'youtube'            => esc_html__('Youtube', 'simple-days'),
      );

    //select sanitization function
      function sns_link_name_sanitize($input){
          //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
          $input = sanitize_key($input);
          //get the list of possible select options
          $choices = array(
                            'none'               => '-',
                            'facebook-square'    => 'Facebook',
                            'feedly'             => 'Feedly',
                            'flickr'             => 'Flickr',
                            'github-square'      => 'Github',
                            'google-plus-square' => 'Google+',
                            'hatena'             => 'Hatena Bookmark',
                            'instagram'          => 'Instagram',
                            'line'               => 'Line',
                            'linkedin'           => 'LinkedIn',
                            'pinterest-square'   => 'Pinterest',
                            'tumblr-square'      => 'Tumblr',
                            'twitter-square'     => 'Twitter',
                            'vimeo-square'       => 'Vimeo',
                            'youtube'            => 'Youtube',
                          );
          //return input if valid or return default option
          return ( array_key_exists( $input, $choices ) ? $input : '' );
      }






      $i = 1;
      while($i <= 10){
        $wp_customize->add_setting( 'simple_days_sns_icon_'.$i,array(
          'default'       => 'none',
          'sanitize_callback' => 'sns_link_name_sanitize',
        ));
        $wp_customize->add_control('simple_days_sns_icon_'.$i,array(
          
          'label'   => sprintf(esc_html__( 'Social Icon #%s', 'simple-days'),$i),
          'section' => 'simple_days_sns',
          'type'    => 'select',
          'choices' => $sns_link_name,
          'priority'  => $i+100,
        ));
        $wp_customize->add_setting( 'simple_days_sns_url_'.$i,
          array(
              'default'     => '',
              'sanitize_callback' => 'esc_url_raw',
          ));
        $wp_customize->add_control( 'simple_days_sns_url_'.$i,
          array(
              
              'label'     => sprintf(esc_html__( 'URL for #%s Social Icon', 'simple-days' ),$i),
              'section'     => 'simple_days_sns',
              'type'        => 'url',
              'priority'     => $i+100,
          ));
        $i++;
      }


      $wp_customize->add_setting('breadcrumbs',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('breadcrumbs',array(
        'section' => 'simple_days_breadcrumbs',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'breadcrumbs', array(
         'selector' => '#breadcrumb',
      ));

      $wp_customize->add_section('simple_days_breadcrumbs',array(
        'title' => esc_html__('Breadcrumbs','simple-days'),
        'panel' => 'simple_days_setting',
      ));


      $wp_customize->add_setting( 'simple_days_breadcrumbs_display',array(
        'default'    => 1,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_breadcrumbs_display',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Breadcrumbs', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type' => 'checkbox',
      ));




      $delimiter = ' &raquo; ';
      $wp_customize->add_setting( 'simple_days_breadcrumbs_delimiter',array(
        'default'           => $delimiter,
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_breadcrumbs_delimiter',array(
        'label'   => esc_html__( 'Delimiter', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type'    => 'editor',
      ));

      $wp_customize->add_setting( 'simple_days_breadcrumbs_homeicon',array(
        'default'           => 'fas fa-home',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_breadcrumbs_homeicon',array(
        'label'   => esc_html__( 'Home icon', 'simple-days'),
        'description' => esc_html__('Support Font Awesome5 only.', 'simple-days').esc_html__('default&#58;', 'simple-days').esc_html('fas fa-home'),
        'section' => 'simple_days_breadcrumbs',
        'type'    => 'editor',
      ));

      $wp_customize->add_setting( 'simple_days_breadcrumbs_treeicon',array(
        'default'           => 'far fa-folder-open',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_breadcrumbs_treeicon',array(
        'label'   => esc_html__( 'Tree icon', 'simple-days'),
        'description' => esc_html__('Support Font Awesome5 only.', 'simple-days').esc_html__('default&#58;', 'simple-days').esc_html('far fa-folder-open'),
        'section' => 'simple_days_breadcrumbs',
        'type'    => 'editor',
      ));

      $wp_customize->add_setting( 'simple_days_breadcrumbs_currenticon',array(
        'default'           => 'far fa-file-alt',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_breadcrumbs_currenticon',array(
        'label'   => esc_html__( 'Current icon', 'simple-days'),
        'description' => esc_html__('Support Font Awesome5 only.', 'simple-days').esc_html__('default&#58;', 'simple-days').esc_html('far fa-file-alt'),
        'section' => 'simple_days_breadcrumbs',
        'type'    => 'editor',
      ));


      $wp_customize->add_setting( 'simple_days_breadcrumbs_current',array(
        'default'    => 1,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_breadcrumbs_current',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Current name', 'simple-days'),
        'section' => 'simple_days_breadcrumbs',
        'type' => 'checkbox',
      ));


      $wp_customize->add_section('simple_days_single',array(
        'title' => esc_html__('Single Post','simple-days'),
        'panel' => 'simple_days_setting',
      ));


      $wp_customize->add_setting('single_thumbnail',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('single_thumbnail',array(
        'section' => 'simple_days_single',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'single_thumbnail', array(
         'selector' => '.single_thumbnail',
      ));

      $wp_customize->add_setting( 'simple_days_single_thumbnail',array(
        'default'    => 1,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_single_thumbnail',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Thumbnail', 'simple-days'),
        'section' => 'simple_days_single',
        'type' => 'checkbox',
      ));


      $wp_customize->add_setting('author_profile',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('author_profile',array(
        'section' => 'simple_days_single',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'author_profile', array(
         'selector' => '.tabs',
      ));

      $wp_customize->add_setting( 'simple_days_single_author_profile',array(
        'default'    => 1,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control('simple_days_single_author_profile',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('About the author(Author profile)', 'simple-days'),
        'section' => 'simple_days_single',
        'type' => 'checkbox',
      ));



      $wp_customize->add_setting('related_post',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('related_post',array(
        'section' => 'simple_days_single',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'related_post', array(
         'selector' => '#related_posts',
      ));

      $wp_customize->add_setting( 'simple_days_single_related_post',array(
        'default'    => 1,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_single_related_post',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Related Posts', 'simple-days'),
        'section' => 'simple_days_single',
        'type' => 'checkbox',
      ));

      $wp_customize->add_setting( 'simple_days_single_related_post_number', array(
        'default' => 9,
        'sanitize_callback' => 'absint',
      ));
      $wp_customize->add_control( 'simple_days_single_related_post_number', array(
        'label' => esc_html__( 'Related Posts view count.', 'simple-days' ),
        'description' => esc_html__( 'multiples of 3 (min3 max18)', 'simple-days' ),
        'section' => 'simple_days_single', // Add a default or your own section
        'type' => 'number',
        'input_attrs' => array(
            'min' => '3', 'step' => '3', 'max' => '18',
        ),
      ));



      $wp_customize->add_setting('sns_share',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('sns_share',array(
        'section' => 'simple_days_single',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'sns_share', array(
         'selector' => '.social_share_list',
      ));

      $wp_customize->add_setting( 'simple_days_single_social_share',array(
        'default'    => 1,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_single_social_share',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Social share', 'simple-days'),
        'section' => 'simple_days_single',
        'type' => 'checkbox',
      ));

      $sns_share_name = array(
        'none'               => '-',
        'buffer'             => esc_html__('buffer', 'simple-days'),
        'digg'               => esc_html__('digg', 'simple-days'),
        'mail'               => esc_html__('Email', 'simple-days'),
        'evernote'           => esc_html__('Evernote', 'simple-days'),
        'facebook-square'    => esc_html__('Facebook', 'simple-days'),
        'google-plus-square' => esc_html__('Google+', 'simple-days'),
        'hatena'             => esc_html__('Hatena Bookmark', 'simple-days'),
        'line'               => esc_html__('Line', 'simple-days'),
        'linkedin'           => esc_html__('LinkedIn', 'simple-days'),
        'pinterest-square'   => esc_html__('Pinterest', 'simple-days'),
        'get-pocket'         => esc_html__('Pocket', 'simple-days'),
        'reddit-square'      => esc_html__('Reddit', 'simple-days'),
        'tumblr-square'      => esc_html__('Tumblr', 'simple-days'),
        'twitter-square'     => esc_html__('Twitter', 'simple-days'),
        'whatsapp-square'    => esc_html__('WhatsApp', 'simple-days'),
      );

    //select sanitization function
      function sns_share_name_sanitize($input){
          //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
          $input = sanitize_key($input);
          //get the list of possible select options
          $choices = array(
                            'none'               => '-',
                            'buffer'             => 'buffer',
                            'digg'               => 'digg',
                            'mail'               => 'Email',
                            'evernote'           => 'Evernote',
                            'facebook-square'    => 'Facebook',
                            'google-plus-square' => 'Google+',
                            'hatena'             => 'Hatena Bookmark',
                            'line'               => 'Line',
                            'linkedin'           => 'LinkedIn',
                            'pinterest-square'   => 'Pinterest',
                            'get-pocket'         => 'Pocket',
                            'reddit-square'      => 'Reddit',
                            'tumblr-square'      => 'Tumblr',
                            'twitter-square'     => 'Twitter',
                            'whatsapp-square'    => 'WhatsApp',
                          );
          //return input if valid or return default option
          return ( array_key_exists( $input, $choices ) ? $input : '' );
      }






      $i = 1;
      while($i <= 10){
        $wp_customize->add_setting( 'simple_days_sns_share_'.$i,array(
          'default'       => 'none',
          'sanitize_callback' => 'sns_share_name_sanitize',
        ));
        $wp_customize->add_control('simple_days_sns_share_'.$i,array(
          
          'label'   => sprintf(esc_html__( 'Social share Icon #%s', 'simple-days'),$i),
          'section' => 'simple_days_single',
          'type'    => 'select',
          'choices' => $sns_share_name,
          'priority'  => $i+100,
        ));
        $i++;
      }



      $wp_customize->add_section('simple_days_page',array(
        'title' => esc_html_x('Page', 'customizer' ,'simple-days'),
        'panel' => 'simple_days_setting',
      ));

      $wp_customize->add_setting('page_thumbnail',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('page_thumbnail',array(
        'section' => 'simple_days_page',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'page_thumbnail', array(
         'selector' => '.page_thumbnail',
      ));

      $wp_customize->add_setting( 'simple_days_page_thumbnail',array(
        'default'    => 1,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_thumbnail',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Thumbnail', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));

      $wp_customize->add_setting('page_author',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('page_author',array(
        'section' => 'simple_days_page',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'page_author', array(
         'selector' => '.page_author',
      ));
      $wp_customize->add_setting( 'simple_days_page_author',array(
        'default'    => 0,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_author',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Author', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));


      $wp_customize->add_setting('page_date',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('page_date',array(
        'section' => 'simple_days_page',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'page_date', array(
         'selector' => '.page_date',
      ));
      $wp_customize->add_setting( 'simple_days_page_date',array(
        'default'    => 0,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_page_date',array(
        'label'   => esc_html__( 'Display', 'simple-days'),
        'description' => esc_html__('Date', 'simple-days'),
        'section' => 'simple_days_page',
        'type' => 'checkbox',
      ));


      $wp_customize->add_section('simple_days_amp_setting',array(
        'title' => esc_html__('AMP(beta Ver.)', 'simple-days'),
        'panel' => 'simple_days_setting',
      ));


      $wp_customize->add_setting( 'simple_days_amp',array(
        'default'    => 0,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_amp',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('Accelerated Mobile Pages(AMP)', 'simple-days'),
        'section' => 'simple_days_amp_setting',
        'type' => 'checkbox',
      ));


      $wp_customize->add_setting( 'simple_days_amp_analytics',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_amp_analytics',array(
        'label'   => esc_html__( 'Google Analytics AMP account', 'simple-days'),
        'description' => esc_html__('example&#58;', 'simple-days').esc_html('UA-XXXXXX-Y'),
        'section' => 'simple_days_amp_setting',
        'type'    => 'editor',
      ));



      $wp_customize->add_setting( 'simple_days_amp_logo_img',array(
        'default'    => esc_url(get_template_directory_uri() .'/assets/images/amp-logo.png'),
        'sanitize_callback' => 'simple_days_sanitize_image_file',
      ));
      $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'simple_days_amp_logo_img', array(
        'label' => esc_html__( 'AMP Logo Image', 'simple-days'),
        'description' => __( 'AMP Logo use this image.', 'simple-days').'<br />'.__( 'For more information', 'simple-days').' <a href="'.esc_url('https://developers.google.com/search/docs/data-types/article#amp').'" target="_blank">'.__( 'click here' ).'</a>',
        'section' => 'simple_days_amp_setting',
      )));



  // Add Settings and Controls for Option.
      $wp_customize->add_section('simple_days_option',array(
        'title' => esc_html__('Option', 'simple-days'),
        'panel' => 'simple_days_setting',
      ));

  $wp_customize->add_setting( 'simple_days_ga_analytics', array(
    'default'           => '0',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_ga_analytics', array(
    'label'    => esc_html__( 'Google Analytics', 'simple-days' ),
    'section'  => 'simple_days_option',
    'type'     => 'radio',
    'choices'  => array(
      '0' => esc_html__( 'Disable', 'simple-days' ),
      '1' => esc_html__( 'ga.js', 'simple-days' ),
      '2' => esc_html__( 'gtag.js', 'simple-days' ),
      ),
    )
  );



      $wp_customize->add_setting( 'simple_days_ga_analytics_id',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_ga_analytics_id',array(
        'label'   => esc_html__( 'Google Analytics account', 'simple-days'),
        'description' => esc_html__('example&#58;', 'simple-days').esc_html('UA-XXXXXX-Y'),
        'section' => 'simple_days_option',
        'type'    => 'editor',
      ));

      $wp_customize->add_setting( 'simple_days_google_site_verification',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_google_site_verification',array(
        'label'   => esc_html__( 'Google Site Verification', 'simple-days'),
        'description' => esc_html__('example&#58;', 'simple-days').esc_html('1234567890AbCdeFghIjKLMnoPQrstuVWXYz'),
        'section' => 'simple_days_option',
        'type'    => 'editor',
      ));

      $wp_customize->add_setting( 'simple_days_ogp',array(
        'default'    => 0,
        'sanitize_callback' => 'sanitize_text_field',
      ));
      $wp_customize->add_control( 'simple_days_ogp',array(
        'label'   => esc_html__( 'Enable', 'simple-days'),
        'description' => esc_html__('add metadata for Open Graph protocol(OGP)', 'simple-days'),
        'section' => 'simple_days_option',
        'type' => 'checkbox',
      ));



      $wp_customize->add_setting( 'simple_days_ogp_logo_img',array(
        'default'    => esc_url(get_template_directory_uri() .'/assets/images/ogp.jpg'),
        'sanitize_callback' => 'simple_days_sanitize_image_file',
      ));
      $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'simple_days_ogp_logo_img', array(
        'label' => esc_html__( 'OGP Image', 'simple-days'),
        'description' => esc_html__( 'If no thumbnail or home page then use this image.', 'simple-days'),
        'section' => 'simple_days_option',
      )));











      $wp_customize->add_setting( 'simple_days_facebook_app_id',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_facebook_app_id',array(
        'label'   => esc_html__( 'Facebook App ID', 'simple-days'),
        'description' => esc_html__('example&#58;', 'simple-days').esc_html('1234567890'),
        'section' => 'simple_days_option',
        'type'    => 'editor',
      ));


      $wp_customize->add_setting( 'simple_days_facebook_admins',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_facebook_admins',array(
        'label'   => esc_html__( 'Facebook fb:admins', 'simple-days'),
        'description' => esc_html__('example&#58;', 'simple-days').esc_html('1234567890'),
        'section' => 'simple_days_option',
        'type'    => 'editor',
      ));


  $wp_customize->add_setting( 'simple_days_twitter_card', array(
    'default'           => '0',
    'sanitize_callback' => 'simple_days_sanitize_radio',
    )
  );
  $wp_customize->add_control( 'simple_days_twitter_card', array(
    'label'    => esc_html__( 'Twitter Card', 'simple-days' ),
    'section'  => 'simple_days_option',
    'type'     => 'radio',
    'choices'  => array(
      '0' => esc_html__( 'Disable', 'simple-days' ),
      'summary' => esc_html__( 'Summary Card', 'simple-days' ),
      'summary_large_image' => esc_html__( 'Summary Card with Large Image', 'simple-days' ),
      ),
    )
  );

      $wp_customize->add_setting( 'simple_days_twitter_user_name',array(
        'default'           => '',
        'sanitize_callback' => 'wp_strip_all_tags',
      ));
      $wp_customize->add_control('simple_days_twitter_user_name',array(
        'label'   => esc_html__( '@username of Twitter', 'simple-days'),
        'description' => esc_html__('example&#58;', 'simple-days').esc_html('@twitter'),
        'section' => 'simple_days_option',
        'type'    => 'editor',
      ));



      
      $wp_customize->add_setting('copyright',array('sanitize_callback' => 'absint',));
      $wp_customize->add_control('copyright',array(
        'section' => 'simple_days_option',
        'type' => 'hidden'
      ));
      $wp_customize->selective_refresh->add_partial( 'copyright', array(
         'selector' => '.credit',
      ));

      $allowed_html = array(
        'a' => array( 'href' => array (), 'onclick' => array (), 'target' => array(), 'title' => array() ),
        'br' => array(),
        'strong' => array(),
        'b' => array(),
      );
      $copyright = '&copy; ';
      $wp_customize->add_setting( 'simple_days_copyright_text',array(
        'default'           => $copyright.esc_html( date_i18n(__('Y','simple-days'))).' <a href="'. esc_url( home_url() ).'">'. get_bloginfo('name').'</a>.',
        'sanitize_callback' => 'wp_kses_post',
      ));
      $wp_customize->add_control('simple_days_copyright_text',array(
        'label'   => esc_html__( 'Copyright', 'simple-days'),
        'section' => 'simple_days_option',
        'type'    => 'textarea',
      ));



      //Link Color
      $wp_customize->add_setting( 'simple_days_background_color',array(
            'default'           => define("simple_days_background_color", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize,
         'simple_days_background_color',array(
            'label'      => esc_html__( 'Background Color', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;fff'),
      )));
      //Link Color
      $wp_customize->add_setting( 'link_textcolor',array(
            'default'           => define("link_textcolor", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize,
         'link_textcolor',array(
            'label'      => esc_html__( 'Link Color', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;07a'),
      )));
      //Link Hover Color
      $wp_customize->add_setting( 'link_hover_color',array(
            'default'           => define("link_hover_color", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control(
         $wp_customize,'link_hover_color',array(
            'label'      => esc_html__( 'Link Hover Color', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;d42'),
      )));
      //Blog Title Color
      $wp_customize->add_setting( 'blog_name',array(
            'default'           => define("blog_name", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control(
         $wp_customize,'blog_name',array(
            'label'      => esc_html__( 'Site Title', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;07a'),
      )));
      //Blog description Color
      $wp_customize->add_setting( 'blog_description',array(
            'default'           => define("blog_description", ""),
            'sanitize_callback' => 'sanitize_hex_color',
      ));
      $wp_customize->add_control( new WP_Customize_Color_Control(
         $wp_customize,'blog_description',array(
            'label'      => esc_html__( 'Blog Description', 'simple-days' ),
            'section'    => 'colors',
            'description' => esc_html__('default&#58;', 'simple-days').esc_html('&#35;07a'),
      )));

      //delete header textcolor control
      $wp_customize->remove_control("header_textcolor");
      $wp_customize->remove_control("background_color");
      
      if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'blogname', array(
        'selector' => '.site_title',
        'render_callback' => 'simple_days_customize_partial_blogname',
        ) );
      }
      $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
   }

   function simple_days_customize_partial_blogname() {
	    bloginfo( 'name' );
   }

   public static function header_output() {

      if ( !is_amp() ){ ?>
      <!--Customizer CSS-->
      <style type="text/css">
           <?php self::generate_css('body', 'background-color', 'simple_days_background_color'); ?>
           <?php self::generate_css('a', 'color', 'link_textcolor'); ?>
           <?php self::generate_css('a:hover', 'color', 'link_hover_color'); ?>
           <?php self::generate_css('.description_tooltip', 'color', 'blog_name'); ?>
           <?php self::generate_css('.description_tooltip:after', 'color', 'blog_description'); ?>
           <?php $header_image = get_header_image();
           if (!empty( $header_image )){ ?>
             #site_header {
                 background-image: url(<?php header_image(); ?>);
                 background-size: cover;
             }
           <?php } ?>
           <?php if(get_theme_mod( 'simple_days_sidebar_layout','3') == 1){
                    echo ' .sidebar{-webkit-box-ordinal-group:1;-ms-flex-order:1;-webkit-order:1;order:1;margin: 0 30px 0 0;} ';
                 }
           ?>
      </style>
      <!--/Customizer CSS-->
<?php }
   }

    /**
     * <head> 内に出力する CSS を作成します。
     * $mod_name 設定が未定義の場合は、何も出力しません。
     *
     * @uses get_theme_mod()
     * @param string $selector CSSセレクタ。
     * @param string $style 変更する CSS *プロパティ* 名。
     * @param string $mod_name 'theme_mod' 設定の名前。
     * @param string $prefix （任意）CSS プロパティの前に出力する内容。
     * @param string $postfix （任意）CSS プロパティの後に出力する内容。
     * @param bool $echo （任意）出力するか否か (デフォルト：true)。
     * @return string セレクタとプロパティからなる1行の CSS を返します。
     * @since MyTheme 1.0
     */
    public static function generate_css( $selector, $style, $mod_name, $prefix='', $postfix='', $echo=true ) {
      $return = '';
      $mod = get_theme_mod($mod_name);
      if ( ! empty( $mod ) ) {
         $return = sprintf('%s { %s:%s; }',
            $selector,
            $style,
            $prefix.$mod.$postfix
         );
         if ( $echo ) {
            echo esc_attr($return);
         }
      }
      return $return;
    }
}

// Setup the Theme Customizer settings and controls...
add_action( 'customize_register' , array( 'Simple_Days_Customize' , 'register' ) );

// Output custom CSS to live site
add_action( 'wp_head' , array( 'Simple_Days_Customize' , 'header_output' ) );